@@ -11,11 +11,27 @@ class ArraySetItemHandler(AbstractCommandHandler):
                 raise Exception("ArraySetItemHandler parameters mismatch!")
 
             array = command.payload[0]
-            value = command.payload[1]
-            indexes = command.payload[2:]
+
+            value = command.payload[2]
+            if isinstance(command.payload[1], list):
+                indexes = command.payload[1]
+            else:
+                indexes = [command.payload[1]]
+
+            if isinstance(command.payload[0], dict):
+                array[indexes[0]] = value
+
+            # one-dimensional array
             if len(indexes) == 1:
                 array[indexes[0]] = value
-                return 0
+            # multi-dimensional array
+            else:
+                for i in range((len(indexes)-1)):
+                    array = array[indexes[i]]
+
+                array[indexes[-1]] = value
+
+            return 0
 
         except Exception as e:
             exc_type, exc_value = type(e), e
